@@ -536,89 +536,15 @@ class BatchHandler(object):
 
     def locate_product_for_entry(self, session, entry, **kwargs):
         """
-        This method aims to provide sane default logic for locating a
-        :class:`~rattail.db.model.products.Product` record for the given
-        "entry" - which is assumed to be a string, i.e. "as-is" from whatever
-        data source.
-
-        Note that any batch handler is free to override this, and certainly
-        some batches will never need it anyway.  The goal is more to establish
-        a good API pattern, but the handler logic itself can vary.
-
-        Also, this default logic will try to honor the "configured" product key
-        field, and prefer that when attempting the lookup.
+        TODO: Deprecated; use ProductsHandler method instead.
         """
         # don't bother if we're given empty "entry" value
         if not entry:
             return
 
-        # if entry is a proper GPC then we kind of have only one thing to do
-        if isinstance(entry, GPC):
-            return api.get_product_by_upc(session, entry)
-
-        # try to locate product by uuid before other, more specific key
-        # if kwargs.get('try_uuid', True):
-        product = session.query(model.Product).get(entry)
-        if product:
-            return product
-
-        # prefer caller-provided key over configured key
-        product_key = kwargs.get('product_key')
-        if not product_key:
-            product_key = self.config.product_key()
-
-        if product_key == 'upc':
-
-            if entry.isdigit():
-
-                # we first assume the user entry *does* include check digit
-                provided = GPC(entry, calc_check_digit=False)
-                product = api.get_product_by_upc(session, provided)
-                if product:
-                    return product
-
-                # but we can also calculate a check digit and try that
-                checked = GPC(entry, calc_check_digit='upc')
-                product = api.get_product_by_upc(session, checked)
-                if product:
-                    return product
-
-                # one last trick is to expand UPC-E to UPC-A and then reattempt
-                # the lookup, *with* check digit (since it would be known)
-                if len(entry) in (6, 8):
-                    checked = GPC(upce_to_upca(entry), calc_check_digit='upc')
-                    product = api.get_product_by_upc(session, checked)
-                    if product:
-                        return product
-
-        elif product_key == 'item_id':
-
-            # try to locate product by item_id
-            product = api.get_product_by_item_id(session, entry)
-            if product:
-                return product
-
-        elif product_key == 'scancode':
-
-            # try to locate product by scancode
-            product = api.get_product_by_scancode(session, entry)
-            if product:
-                return product
-
-        # if we made it this far, lookup by product key failed.
-
-        # try a vendor item code lookup, only if caller requests it
-        if kwargs.get('lookup_vendor_code'):
-            product = api.get_product_by_vendor_code(session, entry,
-                                                     vendor=kwargs.get('vendor'))
-            if product:
-                return product
-
-        # try an "alternate code" lookup, only if caller requests it
-        if kwargs.get('lookup_by_code'):
-            product = api.get_product_by_code(session, entry)
-            if product:
-                return product
+        products_handler = self.app.get_products_handler()
+        return products_handler.locate_product_for_entry(session, entry,
+                                                         **kwargs)
 
     def remove_row(self, row):
         """
@@ -968,27 +894,9 @@ def get_batch_types(config):
     return keys
 
 
-def get_batch_handler(config, batch_key, default=None, error=True):
-    """
-    Returns a batch handler object corresponding to the given batch key.
-
-    Note that this returns the "default" handler for the given batch type, of
-    which there can only be one, determined by config.  If you need a specific
-    handler then you should create it yourself; this function is useful when
-    you just want the default handler.
-    """
-    # spec is assumed to come from config/settings if present, otherwise
-    # caller-supplied default is assumed
-    spec = config.get('rattail.batch', '{}.handler'.format(batch_key),
-                      default=default)
-
-    # if none of the above gave us a spec, check for common 'importer' type
-    if not spec and batch_key == 'importer':
-        spec = 'rattail.batch.importer:ImporterBatchHandler'
-
-    if error and not spec:
-        raise ValueError("handler spec not found for batch type: {}".format(
-            batch_key))
-
-    handler = load_object(spec)(config)
-    return handler
+def get_batch_handler(config, batch_key, default=None, error=True): # pragma: no cover
+    warnings.warn("function is deprecated; please use "
+                  "`app.get_batch_handler() instead",
+                  DeprecationWarning)
+    app = config.get_app()
+    return app.get_batch_handler(batch_key, default=default, error=error)
