@@ -545,12 +545,12 @@ class EmailBouncer(Subcommand):
 
         parser.add_argument('-p', '--pidfile', metavar='PATH', default='/var/run/rattail/bouncer.pid',
                             help="Path to PID file.")
-        parser.add_argument('--daemonize', action='store_true', default=True, # TODO: should default to False
-                            help="Daemonize when starting.")
+        parser.add_argument('--daemonize', action='store_true',
+                            help="DEPRECATED")
         parser.add_argument('--no-daemonize',
-                            '-D', '--do-not-daemonize', # TODO: (re)move these?
+                            '-D', '--do-not-daemonize',
                             action='store_false', dest='daemonize',
-                            help="Do not daemonize when starting.")
+                            help="DEPRECATED")
 
     def run(self, args):
         from rattail.bouncer.daemon import BouncerDaemon
@@ -560,12 +560,9 @@ class EmailBouncer(Subcommand):
             daemon.stop()
         else: # start
             try:
-                daemon.start(daemonize=args.daemonize)
+                daemon.start(daemonize=False)
             except KeyboardInterrupt:
-                if not args.daemonize:
-                    self.stderr.write("Interrupted.\n")
-                else:
-                    raise
+                self.stderr.write("Interrupted.\n")
 
 
 class DateOrganize(Subcommand):
@@ -594,45 +591,6 @@ class DateOrganize(Subcommand):
                     shutil.move(path, datedir)
 
 
-class DatabaseSyncCommand(Subcommand):
-    """
-    Controls the database synchronization service.
-    """
-
-    name = 'dbsync'
-    description = "Manage the database synchronization service"
-
-    def add_parser_args(self, parser):
-        subparsers = parser.add_subparsers(title='subcommands')
-
-        start = subparsers.add_parser('start', help="Start service")
-        start.set_defaults(subcommand='start')
-        stop = subparsers.add_parser('stop', help="Stop service")
-        stop.set_defaults(subcommand='stop')
-
-        if sys.platform == 'linux2':
-            parser.add_argument('-p', '--pidfile',
-                                help="Path to PID file", metavar='PATH')
-            parser.add_argument('-D', '--do-not-daemonize',
-                                action='store_false', dest='daemonize', default=True,
-                                help="Do not daemonize when starting.")
-
-    def run(self, args):
-        from rattail.db.sync import linux as dbsync
-
-        if args.subcommand == 'start':
-            try:
-                dbsync.start_daemon(self.config, args.pidfile, args.daemonize)
-            except KeyboardInterrupt:
-                if not args.daemonize:
-                    self.stderr.write("Interrupted.\n")
-                else:
-                    raise
-
-        elif args.subcommand == 'stop':
-            dbsync.stop_daemon(self.config, args.pidfile)
-
-
 class Dump(Subcommand):
     """
     Do a simple data dump.
@@ -722,12 +680,12 @@ class FileMonitorCommand(Subcommand):
         if sys.platform in ('linux', 'linux2'):
             parser.add_argument('-p', '--pidfile',
                                 help="Path to PID file.", metavar='PATH')
-            parser.add_argument('--daemonize', action='store_true', default=True, # TODO: should default to False
-                                help="Daemonize when starting.")
+            parser.add_argument('--daemonize', action='store_true',
+                                help="DEPRECATED")
             parser.add_argument('--no-daemonize',
-                                '-D', '--do-not-daemonize', # TODO: (re)move these?
+                                '-D', '--do-not-daemonize',
                                 action='store_false', dest='daemonize',
-                                help="Do not daemonize when starting.")
+                                help="DEPRECATED")
 
         elif sys.platform == 'win32': # pragma no cover
 
@@ -749,7 +707,7 @@ class FileMonitorCommand(Subcommand):
             from rattail.filemon import linux as filemon
 
             if args.subcommand == 'start':
-                filemon.start_daemon(self.config, args.pidfile, args.daemonize)
+                filemon.start_daemon(self.config, args.pidfile)
 
             elif args.subcommand == 'stop':
                 filemon.stop_daemon(self.config, args.pidfile)
