@@ -334,6 +334,8 @@ class RattailConfig(object):
         value = self.get(*args, **kwargs)
         if value is None:
             return None
+        if value == '' and 'default' in kwargs:
+            return kwargs['default']
         if isinstance(value, int):
             return value
         return int(value)
@@ -403,8 +405,10 @@ class RattailConfig(object):
         if necessary.
         """
         if not hasattr(self, 'app'):
-            from rattail.app import make_app
-            self.app = make_app(self)
+            spec = self.get('rattail', 'app.handler',
+                            default='rattail.app:AppHandler')
+            factory = load_object(spec)
+            self.app = factory(self)
         return self.app
 
     def app_package(self, default=None):
@@ -736,8 +740,8 @@ def make_config(files=None, usedb=None, preferdb=None, env=None, winsvc=None, ex
         warnings.filterwarnings(
             'ignore',
             r'^The psycopg2 wheel package will be renamed from release 2\.8; in order to keep '
-            'installing from binary please use "pip install psycopg2-binary" instead\. For details '
-            'see: <http://initd.org/psycopg/docs/install.html#binary-install-from-pypi>\.',
+            r'installing from binary please use "pip install psycopg2-binary" instead\. For details '
+            r'see: <http://initd.org/psycopg/docs/install.html#binary-install-from-pypi>\.',
             UserWarning,
             r'^psycopg2$',
         )
@@ -874,6 +878,7 @@ class ConfigProfile(object):
     def __init__(self, config, key, **kwargs):
         self.config = config
         self.key = key
+        self.prefix = kwargs.pop('prefix', key)
         self.load()
 
     def load(self):
@@ -907,17 +912,20 @@ class ConfigProfile(object):
         raise NotImplementedError
 
     def _config_string(self, option, **kwargs):
-        return self.config.get(self.section, '{0}.{1}'.format(self.key, option), **kwargs)
+        return self.config.get(self.section,
+                               '{}.{}'.format(self.prefix, option),
+                               **kwargs)
 
     def _config_boolean(self, option, default=None):
-        return self.config.getbool(self.section, '{0}.{1}'.format(self.key, option),
+        return self.config.getbool(self.section,
+                                   '{}.{}'.format(self.prefix, option),
                                    default=default)
 
     def _config_int(self, option, minimum=1, default=None):
         """
         Retrieve the *integer* value for the given option.
         """
-        option = '{}.{}'.format(self.key, option)
+        option = '{}.{}'.format(self.prefix, option)
 
         # try to read value from config
         value = self.config.getint(self.section, option)
@@ -958,7 +966,7 @@ class ConfigProfile(object):
         if sum(specs) != 1:
             raise ConfigurationError(
                 "Monitor profile '{}' (action '{}') must have exactly one of: "
-                "function, class, command".format(self.key, name))
+                "function, class, command".format(self.prefix, name))
 
         action = ConfigProfileAction()
         action.config = self.config
@@ -976,7 +984,7 @@ class ConfigProfile(object):
         action.args = self._config_list('action.{}.args'.format(name))
 
         action.kwargs = {}
-        pattern = re.compile(r'^{}\.action\.{}\.kwarg\.(?P<keyword>\w+)$'.format(self.key, name), re.IGNORECASE)
+        pattern = re.compile(r'^{}\.action\.{}\.kwarg\.(?P<keyword>\w+)$'.format(self.prefix, name), re.IGNORECASE)
 
         # TODO: this should not be referencing the config parser directly!
         # (but we have no other way yet, to know which options are defined)
