@@ -47,6 +47,7 @@ class ProblemReportHandler(object):
         self.config = config
         self.dry_run = dry_run
         self.progress = progress
+        self.app = self.config.get_app()
         self.enum = self.config.get_enum()
 
     def progress_loop(self, func, items, factory=None, **kwargs):
@@ -188,6 +189,7 @@ class ProblemReportHandler(object):
         context.update({
             'report': report,
             'problems': problems,
+            'app': self.app,
             'enum': self.enum,
             'render_time': self.render_time,
         })
